repo
stringclasses
15 values
fix_commit
stringlengths
40
40
buggy_commit
stringlengths
40
40
message
stringlengths
3
64.3k
files
listlengths
1
300
timestamp
timestamp[s]date
2013-03-13 20:45:00
2026-04-11 07:48:46
denoland/deno
ee6c66b9e9b8277327811564a34124b109927bd3
ec9de01efdc65b3b04b8fe42ba7444d668ae9eb0
fix(ext/node): handle empty writes in chunked HTTP requests (#31066)
[ { "path": "ext/node/polyfills/_http_outgoing.ts", "patch": "@@ -561,6 +561,10 @@ Object.defineProperties(\n });\n }\n });\n+ } else {\n+ // For empty writes, call callback and emit drain to maintain flow control\n+ callback?.();\n+ this.emit(\"drain\")...
2025-10-28T01:38:49
vuejs/vue
2b588b754e5d9c2eea31c56eb735afd6ce37ec5c
43211fd519f462af2530556d905b38d942f61294
Update ComponentOptions (#3651) * Update ComponentOptions * Make ComponentOptions as a Generic Interface * Update some interfaces and types related to ComponentOptions * Update tests * Fix
[ { "path": "types/index.d.ts", "patch": "@@ -6,12 +6,12 @@ import * as VNode from \"./vnode\";\n // `Vue` in `export = Vue` must be a namespace\n // All available types are exported via this namespace\n declare namespace Vue {\n- export type ComponentOptions = Options.ComponentOptions;\n+ export type Compo...
2016-09-13T23:59:14
huggingface/transformers
98c8523434672da086982420faba9350431c270c
767f8a4c75dba4d5d2aa90de5030967c7c16bd87
Fix more dates in model cards and wrong modalities in _toctree.yml (#40955) * Fix model cards and modalities in toctree * fix new models
[ { "path": "docs/source/en/_toctree.yml", "patch": "@@ -439,6 +439,8 @@\n title: DeBERTa\n - local: model_doc/deberta-v2\n title: DeBERTa-v2\n+ - local: model_doc/deepseek_v2\n+ title: DeepSeek-V2\n - local: model_doc/deepseek_v3\n title: DeepSeek-V3\n - ...
2025-09-19T13:47:28
ggml-org/llama.cpp
029bb39eb1e7ae0e5df817ce97931abcd5fa52a9
30649cab657d87ac46692332a76e1b75d5d22e00
ci : enable RVV1.0 native build (#15386) * Changed the CI file to hw * Changed the CI file to hw * Added to sudoers for apt * Removed the clone command and used checkout * Added libcurl * Added gcc-14 * Checking gcc --version * added gcc-14 symlink * added CC and C++ variables * Added the gguf weight * Chang...
[ { "path": ".github/workflows/build-riscv-native.yml", "patch": "@@ -1,10 +1,11 @@\n name: Build on RISCV Linux Machine by Cloud-V\n on:\n+ pull_request:\n workflow_dispatch:\n workflow_call:\n \n jobs:\n- bianbu-riscv64-native: # Bianbu 2.2\n+ debian-13-riscv64-native: # Bianbu 2.2\n runs-on: sel...
2025-08-21T12:52:16
denoland/deno
ec9de01efdc65b3b04b8fe42ba7444d668ae9eb0
202a8c054b99507a0dd0f1bfc61b81f002f84320
fix(ext/http): display localhost url once on windows (#31088)
[ { "path": "ext/http/00_serve.ts", "patch": "@@ -933,7 +933,8 @@ function serveInner(options, handler) {\n const host = formatHostName(addr.hostname);\n \n const url = `${scheme}${host}:${addr.port}/`;\n- const helper = addr.hostname === \"0.0.0.0\" || addr.hostname === \"::\"\n+ const ...
2025-10-27T19:22:23
huggingface/transformers
767f8a4c75dba4d5d2aa90de5030967c7c16bd87
9d9c4d24c50cc1e3a24eac0e1af8267b5c43010d
Fix typoes in src and tests (#40845) Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
[ { "path": "src/transformers/generation/continuous_batching/cache.py", "patch": "@@ -79,7 +79,7 @@ class PagedAttentionCache:\n layer group, and the shape of the cache tensor is `[num_blocks * block_size, num_heads, head_size]`.\n \n Grouping layers into groups is useful because when we allocate ...
2025-09-19T13:18:38
vuejs/vue
45ff6218c15f118d926a27ac90e274f3c999d77f
d0c13c7e6672d5f36e88179ca75d8c04b9eb0115
handle multiline atribute value parsing in IE (fix #3663)
[ { "path": "flow/compiler.js", "patch": "@@ -14,6 +14,7 @@ declare type CompilerOptions = {\n preserveWhitespace?: boolean;\n isFromDOM?: boolean;\n shouldDecodeTags?: boolean;\n+ shouldDecodeNewlines?: boolean;\n \n // runtime user-configurable\n delimiters?: [string, string]; // template delimit...
2016-09-13T12:43:25
ggml-org/llama.cpp
b108e429043ee5c9fc8fa4957a0a52c3e490d5c9
245be739df942861ddc52331b095b40f18e2a3f1
ci : fix -Werror=return-type in clip.cpp so ci/run.sh can run without issue (#15221) * Fix -Werror=return-type so ci/run.sh can run * Update tools/mtmd/clip.cpp Co-authored-by: Diego Devesa <slarengh@gmail.com> * Remove false now that we have abort --------- Co-authored-by: Diego Devesa <slarengh@gmail.com>
[ { "path": "tools/mtmd/clip.cpp", "patch": "@@ -3581,10 +3581,10 @@ bool clip_image_preprocess(struct clip_ctx * ctx, const clip_image_u8 * img, str\n }\n \n return true;\n-\n+ } else {\n+ GGML_ABORT(\"Unknown image preprocessing type\");\n }\n \n- GGML_ASSERT(false && \"Unkn...
2025-08-21T10:06:46
huggingface/transformers
9d9c4d24c50cc1e3a24eac0e1af8267b5c43010d
b4ba4e1da0c77710833a2a9ba86f729b42098e46
Make `EfficientLoFTRModelTest` faster (#41000) * fix * fix * fix --------- Co-authored-by: ydshieh <ydshieh@users.noreply.github.com>
[ { "path": "tests/models/efficientloftr/test_modeling_efficientloftr.py", "patch": "@@ -46,18 +46,18 @@ def __init__(\n self,\n parent,\n batch_size=2,\n- image_width=80,\n- image_height=60,\n- stage_num_blocks: list[int] = [1, 1, 1],\n- out_features: list[...
2025-09-19T12:51:05
denoland/deno
202a8c054b99507a0dd0f1bfc61b81f002f84320
2bf5c78666d7cc03fd7b820d48e7787c0804d09a
Revert "fix(ext/node): fileHandle compatibility" (#31103) Reverts denoland/deno#31094 This has caused node compat tests to fail on main.
[ { "path": "ext/node/polyfills/_fs/_fs_fchmod.ts", "patch": "@@ -10,7 +10,6 @@ import {\n } from \"ext:deno_node/internal/validators.mjs\";\n import { op_fs_fchmod_async, op_fs_fchmod_sync } from \"ext:core/ops\";\n import { primordials } from \"ext:core/mod.js\";\n-import { promisify } from \"ext:deno_node/...
2025-10-27T16:27:50
vuejs/vue
6f8316fe8f8e0a0697af9a625004097ad59eadc9
673dec6040bcfc510866761b38439b9d34dd91f7
toObject should not mutate original objects (fix #3657)
[ { "path": "src/shared/util.js", "patch": "@@ -170,8 +170,8 @@ export function isPlainObject (obj: any): boolean {\n * Merge an Array of Objects into a single Object.\n */\n export function toObject (arr: Array<any>): Object {\n- const res = arr[0] || {}\n- for (let i = 1; i < arr.length; i++) {\n+ cons...
2016-09-11T10:17:59
ggml-org/llama.cpp
b2caf67db1208fd38a0570785c39f7370d906d8a
2f3dbffb17ef782edfd50e5a130cec6e8a7e47f8
convert : make Mistral community chat templates optional via parameter (#15420) * Make Mistral community chat templates optional * Change the flag arg to disable instead of enable community chat templates * Improve error message * Improve help message * Tone down the logger messages
[ { "path": "convert_hf_to_gguf.py", "patch": "@@ -89,13 +89,16 @@ class ModelBase:\n block_count: int\n tensor_map: gguf.TensorNameMap\n \n+ # Mistral format specifics\n is_mistral_format: bool = False\n+ disable_mistral_community_chat_template: bool = False\n \n def __init__(self, dir_...
2025-08-21T09:19:50
huggingface/transformers
b4ba4e1da0c77710833a2a9ba86f729b42098e46
fce746512bc4e10b0749c59935fbf52360479612
[`RMSNorm`] Fix rms norm init for models that center around 1 (#40796) * fix * fixup inits * oops * fixup gemma * fixup modular order * how does this keep happen lol * vaultgemma is new i forgot * remove init check
[ { "path": "src/transformers/models/gemma/modeling_gemma.py", "patch": "@@ -322,6 +322,13 @@ class GemmaPreTrainedModel(PreTrainedModel):\n \"attentions\": GemmaAttention,\n }\n \n+ def _init_weights(self, module):\n+ super()._init_weights(module)\n+\n+ # We initialize with 0s to...
2025-09-19T12:15:36
vuejs/vue
673dec6040bcfc510866761b38439b9d34dd91f7
b47d773c58de077e40edd54a3f5bde2bdfa5fd3d
fix duplicate slot warning spelling
[ { "path": "src/core/instance/render.js", "patch": "@@ -164,7 +164,7 @@ export function renderMixin (Vue: Class<Component>) {\n // warn duplicate slot usage\n if (slotNodes && process.env.NODE_ENV !== 'production') {\n slotNodes._rendered && warn(\n- `Duplicate presense of slot \"${name}...
2016-09-10T08:41:12
denoland/deno
2bf5c78666d7cc03fd7b820d48e7787c0804d09a
20fb456be521f958b889fa3465e75a501fcfd7c5
fix(audit): handle 'review' actions (#31100) Closes https://github.com/denoland/deno/issues/31098
[ { "path": "cli/tools/pm/audit.rs", "patch": "@@ -393,13 +393,13 @@ mod npm {\n if actions.len() == 1 {\n _ =\n writeln!(stdout, \"╰ {} {}\", colors::gray(\"Actions:\"), actions[0]);\n- } else {\n+ } else if actions.len() > 1 {\n _ =\n writeln!(stdout, \...
2025-10-27T11:44:02
ggml-org/llama.cpp
2f3dbffb17ef782edfd50e5a130cec6e8a7e47f8
945e1f12a6b586ebf82fa4fd7f347225e58174c5
common : fix incorrect print of non-ascii characters in the logging (#15466) Signed-off-by: Jie Fu <jiefu@tencent.com>
[ { "path": "common/common.cpp", "patch": "@@ -558,13 +558,6 @@ std::string string_from(const struct llama_context * ctx, const std::vector<llam\n \n auto detokenized = common_token_to_piece(ctx, token);\n \n- detokenized.erase(\n- std::remove_if(\n- detokenized.begin(...
2025-08-21T08:54:34
vuejs/vue
179ec92019dd098487c720ba8d1667bbedb9c380
100a2969aa5c64bd71758c79881cf4531e9907be
fix lint
[ { "path": "src/core/instance/render.js", "patch": "@@ -36,11 +36,11 @@ export function renderMixin (Vue: Class<Component>) {\n _parentVnode\n } = vm.$options\n \n- if (vm._isMounted) { \n- // clone slot nodes on re-renders \n- for (const key in vm.$slots) { \n- vm.$slot...
2016-09-08T11:55:45
huggingface/transformers
ddfa3d4402915b8aafd82b3135cb37af9a5d6b69
46ea7e613d67b29ee71212f453d0aa59b85f7583
blt wip (#38579) * blt wip * cpu version * cpu friendly with full entropy model (real time patching) * adding config file instead of args file * enable MPS * refactoring unused code * single config class in config file * inherit from PreTrainedModel * refactor LMTransformer --> BLTPatcher * add conversion scr...
[ { "path": "docs/source/en/_toctree.yml", "patch": "@@ -407,6 +407,8 @@\n title: Blenderbot Small\n - local: model_doc/bloom\n title: BLOOM\n+ - local: model_doc/blt\n+ title: BLT\n - local: model_doc/bort\n title: BORT\n - local: model_doc/byt5", "ad...
2025-09-19T09:55:55
denoland/deno
20fb456be521f958b889fa3465e75a501fcfd7c5
3a1ae29327061c5a26b0ca9d50cb0c3181868544
fix(ext/node): cpus() should not error when there's no cpu info (#31097) os.cpus() in Node returns an empty array if there is no cpu info. This is also specified in [its documentation](https://nodejs.org/api/os.html#oscpus:~:text=The%20array%20will%20be%20empty%20if%20no%20CPU%20information%20is%20available): "The arr...
[ { "path": "ext/node/ops/os/mod.rs", "patch": "@@ -24,9 +24,6 @@ pub enum OsError {\n #[inherit]\n PermissionCheckError,\n ),\n- #[class(type)]\n- #[error(\"Failed to get cpu info\")]\n- FailedToGetCpuInfo,\n #[class(inherit)]\n #[error(\"Failed to get user info\")]\n FailedToGetUserInfo(\...
2025-10-27T11:29:08
vuejs/vue
1c4ca4bc08b0faf1b457aa02d8a96749e232fb16
7a2c986722447f270354221c13a84deea2e100fd
fix lint
[ { "path": "src/core/vdom/patch.js", "patch": "@@ -82,7 +82,7 @@ export function createPatchFunction (backend) {\n }\n \n function createElm (vnode, insertedVnodeQueue, nested) {\n- let i, elm\n+ let i\n const data = vnode.data\n vnode.isRootInsert = !nested\n if (isDef(data)) {\n@@ -11...
2016-09-08T11:17:30
huggingface/transformers
46ea7e613d67b29ee71212f453d0aa59b85f7583
ebdc17b8e5b3bf5d6391ae8196b2cdb1d6e98e45
[testing] test `num_hidden_layers` being small in model tester (#40992) fix Co-authored-by: ydshieh <ydshieh@users.noreply.github.com>
[ { "path": "tests/models/aya_vision/test_modeling_aya_vision.py", "patch": "@@ -71,7 +71,7 @@ def __init__(\n \"vocab_size\": 99,\n \"hidden_size\": 128,\n \"intermediate_size\": 37,\n- \"num_hidden_layers\": 4,\n+ \"num_hidden_layers\": 2,\n ...
2025-09-19T09:45:07
denoland/deno
3a1ae29327061c5a26b0ca9d50cb0c3181868544
c0ebacba75138789ccd6dc93c1b5bec04f4e6d63
fix(ext/node): fileHandle compatibility (#31094) Towards #29972 Notable changes: - Omits `path` from the `FileHandle` constructor. This includes replacing `utimes` and `chown` with `futimes` and `fchown`. - Handles closing resource ID gracefully to follow node's implementation. Closed resource IDs are marked as `-1`....
[ { "path": "ext/node/polyfills/_fs/_fs_fchmod.ts", "patch": "@@ -10,6 +10,7 @@ import {\n } from \"ext:deno_node/internal/validators.mjs\";\n import { op_fs_fchmod_async, op_fs_fchmod_sync } from \"ext:core/ops\";\n import { primordials } from \"ext:core/mod.js\";\n+import { promisify } from \"ext:deno_node/...
2025-10-27T11:28:23
vuejs/vue
4afccc8eece43956f6f84189923a60d9a5a45e36
f25482dd93a367b1b5ac4c52fb103015279c87cb
proper slot duplication warning (fix #3595)
[ { "path": "flow/component.js", "patch": "@@ -93,6 +93,8 @@ declare interface Component {\n _f: (id: string) => Function;\n // renderList\n _l: (val: any, render: Function) => ?Array<VNode>;\n+ // renderSlot\n+ _t: (name: string, fallback: ?Array<VNode>) => ?Array<VNode>;\n // apply v-bind object\n...
2016-09-08T09:47:22
denoland/deno
c0ebacba75138789ccd6dc93c1b5bec04f4e6d63
5cee3a317d1c9e64a7d6c09763921fe854ad086c
fix(ext/node): handle multiple calls in inspector.Session.post() (#31067) Fixes a panic that occurred when using nested session.post() calls in the node:inspector module. The issue manifested when callbacks from inspector commands (like Profiler.enable) called session.post() again, causing a re-entrant invocation of o...
[ { "path": "ext/node/ops/inspector.rs", "patch": "@@ -167,17 +167,17 @@ where\n })\n }\n \n-#[op2(fast)]\n+#[op2(fast, reentrant)]\n pub fn op_inspector_dispatch(\n- #[cppgc] session: &JSInspectorSession,\n+ #[cppgc] inspector: &JSInspectorSession,\n #[string] message: String,\n ) {\n- if let Some(ses...
2025-10-27T09:46:55
ggml-org/llama.cpp
945e1f12a6b586ebf82fa4fd7f347225e58174c5
1b0db8f6e08951969e2447c2d18bf638effb8f75
ggml : fix condition of im2col on Metal backend (#15460)
[ { "path": "ggml/src/ggml-metal/ggml-metal.m", "patch": "@@ -1846,7 +1846,7 @@ static bool ggml_metal_supports_op(const struct ggml_backend_metal_device_contex\n case GGML_OP_ROPE:\n return true;\n case GGML_OP_IM2COL:\n- return op->src[0]->type == GGML_TYPE_F16;\n+ ...
2025-08-21T05:32:26
vuejs/vue
f25482dd93a367b1b5ac4c52fb103015279c87cb
f541097486c18f7778cc4d12490bc9a46cd0faf1
tiny comment fix
[ { "path": "src/core/vdom/patch.js", "patch": "@@ -332,7 +332,7 @@ export function createPatchFunction (backend) {\n // reuse element for static trees.\n // note we only do this if the vnode is cloned -\n // if the new node is not cloned it means the render functions have been\n- // reset by t...
2016-09-08T09:11:39
denoland/deno
5cee3a317d1c9e64a7d6c09763921fe854ad086c
c20ef4ce8ccca02e25496d94b19fb6f5dc535374
fix(check): support text and bytes imports with --unstable-tsgo (#31084) Fixes https://github.com/denoland/deno/issues/31034.
[ { "path": "cli/tsc/go.rs", "patch": "@@ -60,6 +60,7 @@ fn synthetic_config(\n {\n obj.insert(\"jsx\".to_string(), json!(\"react-jsx\"));\n }\n+ obj.insert(\"allowArbitraryExtensions\".to_string(), json!(true));\n let config = serde_json::to_string(&json!({\n \"compilerOptions\": config,\n ...
2025-10-24T23:41:20
huggingface/transformers
155f7e2e6237bc4f623aecf9bfd97442d5723963
61eff450d39742ac28789fe7a2a133395b133ace
🔴[`Attention`] Bert-based Models Attention Refactor (#38301) * clean start to bert refactor * some test fixes * style * fix last tests * be strict on positional embeddings, fixup according tests * cache support * more cache fixes, new causal API * simplify masks, fix tests for gen * flex attn, static cache su...
[ { "path": "src/transformers/models/albert/modeling_albert.py", "patch": "@@ -14,16 +14,15 @@\n # limitations under the License.\n \"\"\"PyTorch ALBERT model.\"\"\"\n \n-import math\n from dataclasses import dataclass\n-from typing import Optional, Union\n+from typing import Callable, Optional, Union\n \n im...
2025-09-19T09:23:58
ggml-org/llama.cpp
1b0db8f6e08951969e2447c2d18bf638effb8f75
29f538ac630d6544406a0702476e36808a6bd1b3
server : fix webui (#15462) * Fix webui crash after streaming * build webui
[ { "path": "tools/server/webui/src/utils/app.context.tsx", "patch": "@@ -255,7 +255,7 @@ export const AppContextProvider = ({\n if (chunk.error) {\n throw new Error(chunk.error?.message || 'Unknown error');\n }\n- const addedContent = chunk.choices[0].delta.content;\n+ ...
2025-08-21T05:19:22
vuejs/vue
f541097486c18f7778cc4d12490bc9a46cd0faf1
63e4757fbd7e17babe4e9bd4cb0af7d84e3f2a5f
Expose all types via index.d.ts (#3608) * expose all types via index.d.ts * Fix typo
[ { "path": "types/index.d.ts", "patch": "@@ -1,6 +1,33 @@\n import {Vue as _Vue} from \"./vue\";\n+import * as Options from \"./options\";\n+import * as Plugin from \"./plugin\";\n+import * as VNode from \"./vnode\";\n+\n // `Vue` in `export = Vue` must be a namespace\n-declare namespace Vue {}\n+// All avai...
2016-09-08T08:26:01
denoland/deno
eaebf88418dea6c4c454e51b197e396c76863c62
fc7ae0e4282fbd66ee03a26fcd81187b846b0fa6
fix(ext/node): make `kReinitializeHandle` work for TLS wrap (#31079)
[ { "path": "ext/node/polyfills/net.ts", "patch": "@@ -1809,6 +1809,9 @@ Object.defineProperty(Socket.prototype, \"_handle\", {\n Socket.prototype[kReinitializeHandle] = function (handle) {\n this._handle?.close();\n \n+ // Make sure TLS wrap works after reinitialize.\n+ handle.afterConnectTls = this._han...
2025-10-24T08:05:59
huggingface/transformers
61eff450d39742ac28789fe7a2a133395b133ace
5f6e278a5177d8b85945a2cdb6b776dacee34914
Benchmarking v2 GH workflows (#40716) * WIP benchmark v2 workflow * Container was missing * Change to sandbox branch name * Wrong place for image name * Variable declarations * Remove references to file logging * Remove unnecessary step * Fix deps install * Syntax * Add workdir * Add upload feature * typo ...
[ { "path": ".github/workflows/benchmark_v2.yml", "patch": "@@ -0,0 +1,82 @@\n+name: Benchmark v2 Framework\n+\n+on:\n+ workflow_call:\n+ inputs:\n+ runner:\n+ description: 'GH Actions runner group to use'\n+ required: true\n+ type: string\n+ commit_sha:\n+ descriptio...
2025-09-19T08:54:49
ggml-org/llama.cpp
29f538ac630d6544406a0702476e36808a6bd1b3
8ad038c0fdc719ced9fbf921a02cbae9ad79287f
examples : remove references to `make` in examples [no ci] (#15457) This commit removes references to `make` in the examples, as the build system has been updated to use CMake directly and using `make` will now generate an error since Commit 37f10f955f70e0158d50343d0b9a3f92d194daae ("make : remove make in favor of CMa...
[ { "path": "examples/batched.swift/README.md", "patch": "@@ -1,4 +1,5 @@\n This is a swift clone of `examples/batched`.\n \n-$ `make`\n-$ `./llama-batched-swift MODEL_PATH [PROMPT] [PARALLEL]`\n+```bash\n+$ ./llama-batched-swift MODEL_PATH [PROMPT] [PARALLEL]\n+```", "additions": 3, "deletions": 2, ...
2025-08-21T04:12:28
vuejs/vue
63e4757fbd7e17babe4e9bd4cb0af7d84e3f2a5f
d2337dfc3fd4b03b01204efa0256a517c4b78697
key nested children by default (fix #3611)
[ { "path": "src/core/vdom/helpers.js", "patch": "@@ -5,7 +5,8 @@ import VNode from './vnode'\n \n export function normalizeChildren (\n children: any,\n- ns: string | void\n+ ns: string | void,\n+ nestedIndex: number | void\n ): Array<VNode> | void {\n if (isPrimitive(children)) {\n return [create...
2016-09-08T07:54:53
denoland/deno
fc7ae0e4282fbd66ee03a26fcd81187b846b0fa6
0ed74e6c5357ba55088e984d0f527a7c1d0247bf
fix(check): fall back to copying tsgo binary if rename fails (#31074) Fixes https://github.com/denoland/deno/issues/31033.
[ { "path": "cli/tsc/go/setup.rs", "patch": "@@ -31,8 +31,8 @@ pub enum DownloadError {\n InvalidDownloadUrl(String, #[source] deno_core::url::ParseError),\n #[error(\"failed to unpack typescript-go: {0}\")]\n UnpackFailed(#[source] AnyError),\n- #[error(\"failed to rename typescript-go: {0}\")]\n- Re...
2025-10-23T21:00:15
ggml-org/llama.cpp
1bc664a26a1d93a48baf2483a7ff95291ca8bcb8
13aeb7aef284daed4ad07dc14b4b3e2a42b5ea97
server: fix OpenAI API compatibility for usage statistics in chat streams (#15444)
[ { "path": "tools/server/server.cpp", "patch": "@@ -911,6 +911,17 @@ struct server_task_result_cmpl_final : server_task_result {\n {\"model\", oaicompat_model},\n {\"system_fingerprint\", build_info},\n {\"object\", \"chat.completion.chunk\"},\n+ ...
2025-08-20T22:10:08
vuejs/vue
8f4aab201b4f1b6293029aa251f9b9c2bdc13c0a
4061c42748bcf374d2ad54c0a5f46bf258db06da
Fix definitons (#3591) * Fix types * add “FunctionalComponentOptions” and “ContextObject” * fix and update types * Rename * Update vue.d.ts * Update options-test.ts
[ { "path": "types/options.d.ts", "patch": "@@ -1,10 +1,12 @@\n import { Vue } from \"./vue.d\";\n-import { VNode, VNodeDirective } from \"./vnode.d\";\n+import { VNode, VNodeData, VNodeDirective } from \"./vnode.d\";\n \n type Constructor = {\n new (...args: any[]): any;\n }\n \n+type $createElement = type...
2016-09-05T10:53:34
ggml-org/llama.cpp
657b8a77bd01854f99d37a47318fa24f2e7e298f
ec5ab1a36c11dd3efcf4ec8d1ac89a13a8117bc3
chat: handle gpt-oss return/end token inconsistency (#15421) This commit addresses an inconsistency during inference by adding a new member to the `templates_params` struct to indicate whether the chat is in inference mode. This allows the gpt-oss specific function `common_chat_params_init_gpt_oss` to check this flag ...
[ { "path": "common/chat.cpp", "patch": "@@ -147,6 +147,7 @@ struct templates_params {\n json extra_context;\n bool add_bos;\n bool add_eos;\n+ bool is_inference = true;\n };\n \n common_chat_tool_choice common_chat_tool_choice_parse_oaicompat(const std::string & tool_choice) {\n@@ -1336,6 +133...
2025-08-20T12:26:01
denoland/deno
0ed74e6c5357ba55088e984d0f527a7c1d0247bf
6692895b174098536fbe8eba6e83c82a8b8399ed
feat(unstable): add `deno audit` subcommand (#30966) This commit adds a new `deno audit` subcommand that collects all dependencies and queries npm registry for information about known vulnerabilities of used npm packages. ``` $ ../deno/target/debug/deno audit ... ╭ Prototype Pollution Protection Bypass in qs │ Severi...
[ { "path": "cli/args/flags.rs", "patch": "@@ -111,6 +111,17 @@ pub struct AddFlags {\n pub default_registry: Option<DefaultRegistry>,\n }\n \n+#[derive(Clone, Debug, Default, Eq, PartialEq)]\n+pub struct AuditFlags {\n+ pub severity: String,\n+ pub ignore_registry_errors: bool,\n+ pub ignore_unfixable: ...
2025-10-23T16:43:59
vuejs/vue
4061c42748bcf374d2ad54c0a5f46bf258db06da
5a03f52b105788ab92b7f38893d47b46a1515f2b
adapt index.d.ts for end users (#3582) * adapt index.d.ts for end users * fix extend return type
[ { "path": "package.json", "patch": "@@ -3,7 +3,7 @@\n \"version\": \"2.0.0-rc.4\",\n \"description\": \"Reactive, component-oriented view layer for modern web interfaces.\",\n \"main\": \"dist/vue.common.js\",\n- \"typings\": \"index.d.ts\",\n+ \"typings\": \"types/index.d.ts\",\n \"files\": [\n ...
2016-09-04T09:33:25
ggml-org/llama.cpp
ec5ab1a36c11dd3efcf4ec8d1ac89a13a8117bc3
1a99c2d948209d9ea5eac8b6dc0a297107244540
common : fix context shift help message (#15448) Signed-off-by: Jie Fu <jiefu@tencent.com>
[ { "path": "common/arg.cpp", "patch": "@@ -1532,7 +1532,7 @@ common_params_context common_params_parser_init(common_params & params, llama_ex\n ).set_examples({LLAMA_EXAMPLE_MAIN, LLAMA_EXAMPLE_SERVER, LLAMA_EXAMPLE_IMATRIX, LLAMA_EXAMPLE_PERPLEXITY}).set_env(\"LLAMA_ARG_NO_CONTEXT_SHIFT\"));\n add_o...
2025-08-20T10:33:30
denoland/deno
aedd1084d992218d74b85212024dd477ceb55103
41e70e55189bae961b7864015aa9e176038af72b
fix(check): support isolatedDeclarations (#31061)
[ { "path": "cli/tsc/99_main_compiler.js", "patch": "@@ -163,6 +163,9 @@ function exec({ config, debug: debugFlag, rootNames, localOnly }) {\n : ts.sortAndDeduplicateDiagnostics(\n checkFiles.map((s) => program.getSemanticDiagnostics(s)).flat(),\n )),\n+ ...(options.isolatedDeclarations...
2025-10-23T15:08:49
huggingface/transformers
4df2529d79d75f44e70396df5888a32ffa02d61e
5ac3c5171a6b01708e574eaa11fa2a60086d26bc
🚨🚨🚨 Fully remove Tensorflow and Jax support library-wide (#40760) * setup * start the purge * continue the purge * more and more * more * continue the quest: remove loading tf/jax checkpoints * style * fix configs * oups forgot conflict * continue * still grinding * always more * in tje zone * never st...
[ { "path": "README.md", "patch": "@@ -80,7 +80,7 @@ Explore the [Hub](https://huggingface.com/) today to find a model and use Transf\n \n ## Installation\n \n-Transformers works with Python 3.9+ [PyTorch](https://pytorch.org/get-started/locally/) 2.1+, [TensorFlow](https://www.tensorflow.org/install/pip) 2.6...
2025-09-18T16:27:39
vuejs/vue
04eb32e4f06cbff7daab3024d93b8109c0a70786
9727f87e3fe754ef8920ae1154f0d7d69ff061b6
fix typo (#3578)
[ { "path": "packages/vue-template-compiler/README.md", "patch": "@@ -32,7 +32,7 @@ Note the returned function code uses `with` and thus cannot be used in strict mo\n \n #### Options\n \n-It's possible to hook into the compilation process to support custom template features. **However, beware that by injectin...
2016-09-01T02:27:49
ggml-org/llama.cpp
1a99c2d948209d9ea5eac8b6dc0a297107244540
37f10f955f70e0158d50343d0b9a3f92d194daae
cmake : fix target include directories (#15450) * Update docker.yml 修改docker.yml文件中的内容使其停止周期性的运行该workflow,如果想要运行该workflow可以手动启动 * feat:Modify the header file include path 1. There's no llava directory in the tools directory. 2. Because the command `target_include_directories(mtmd PUBLIC .)` is used in the `mtmd` CM...
[ { "path": "tools/server/CMakeLists.txt", "patch": "@@ -33,7 +33,7 @@ endforeach()\n add_executable(${TARGET} ${TARGET_SRCS})\n install(TARGETS ${TARGET} RUNTIME)\n \n-target_include_directories(${TARGET} PRIVATE ../llava)\n+target_include_directories(${TARGET} PRIVATE ../mtmd)\n target_include_directories($...
2025-08-20T10:32:05
denoland/deno
41e70e55189bae961b7864015aa9e176038af72b
4fee1ceb6526cdc5924f5585ecf6da555c82f862
fix: debug log for package.json being found was incorrect (#31062)
[ { "path": "libs/config/workspace/discovery.rs", "patch": "@@ -274,10 +274,12 @@ fn discover_workspace_config_files_for_single_dir<\n &pkg_json_path,\n ) {\n Ok(pkg_json) => {\n- log::debug!(\n- \"package.json file found at '{}'\",\n- pkg_json_path.display...
2025-10-23T08:09:08
vuejs/vue
dfc64e8a110d63177869528e2f9cdc103cf514b4
2998bbfae9c618b49d48152a078e14ecf74607f8
Add TypeScript definitions Add TypeScript definition Remove unnecessary definition Update definitions * separate files * remove unnecessary `{[key: string]: any}` * from singular to plural Update definitions * Add more definitions * Rename filename and interface * Sort definitions * Fix indent Fix Add test * a...
[ { "path": "package.json", "patch": "@@ -17,12 +17,13 @@\n \"dev:compiler\": \"TARGET=web-compiler rollup -w -c build/config.js\",\n \"build\": \"node build/build.js\",\n \"build:ssr\": \"npm run build -- vue.common.js,vue-server-renderer\",\n- \"test\": \"npm run lint && flow check && npm run...
2016-08-23T19:01:30
huggingface/transformers
5ac3c5171a6b01708e574eaa11fa2a60086d26bc
d9d7f6a6b9ee34d33ebf8d140e247134daf84a7b
Track the CI (model) jobs that don't produce test output files (process being killed etc.) (#40981) * fix * fix --------- Co-authored-by: ydshieh <ydshieh@users.noreply.github.com>
[ { "path": ".github/workflows/model_jobs.yml", "patch": "@@ -138,10 +138,16 @@ jobs:\n - name: Run all tests on GPU\n working-directory: /transformers\n run: |\n- PATCH_TESTING_METHODS_TO_COLLECT_OUTPUTS=yes _PATCHED_TESTING_METHODS_OUTPUT_DIR=/transformers/reports/${{ env.mach...
2025-09-18T16:27:27
ggml-org/llama.cpp
a094f381432d92c4bf92d2d6167284316ba73a62
fb22dd07a639e81c7415e30b146f545f1a2f2caf
musa: fix build warnings (#15258) * musa: fix build warnings Signed-off-by: Xiaodong Ye <xiaodong.ye@mthreads.com> * fix warning: comparison of integers of different signs: 'const int' and 'unsigned int' [-Wsign-compare] Signed-off-by: Xiaodong Ye <xiaodong.ye@mthreads.com> --------- Signed-off-by: Xiaodong Ye <x...
[ { "path": "ggml/src/ggml-cuda/add-id.cu", "patch": "@@ -11,14 +11,14 @@ static __global__ void add_id_kernel(\n const int64_t i1 = blockIdx.x;\n const int64_t i2 = blockIdx.y;\n \n- const int i11 = *(int32_t *) ((char *) src2 + i1*sizeof(int32_t) + i2*nb21);\n+ const int i11 = *(const int32_t ...
2025-08-20T02:17:37
denoland/deno
4fee1ceb6526cdc5924f5585ecf6da555c82f862
02f6e49276bb4c03634af4aec4487a5a0a9dbebf
fix(cli/args): empty permissions in config should not require -P (#31063)
[ { "path": "cli/args/mod.rs", "patch": "@@ -1065,12 +1065,15 @@ impl CliOptions {\n let set_config_permission_name = match &self.flags.subcommand {\n DenoSubcommand::Bench(_) => dir\n .to_bench_permissions_config()?\n+ .filter(|permissions| !permissions.permissions.is...
2025-10-23T01:05:22
huggingface/transformers
d9d7f6a6b9ee34d33ebf8d140e247134daf84a7b
738b223f57fdef69e9db2de2f9e1203b43eef251
Revert change in `compile_friendly_resize` (#40645) fix
[ { "path": "src/transformers/image_processing_utils_fast.py", "patch": "@@ -375,9 +375,13 @@ def compile_friendly_resize(\n A wrapper around `F.resize` so that it is compatible with torch.compile when the image is a uint8 tensor.\n \"\"\"\n if image.dtype == torch.uint8:\n- ...
2025-09-18T15:25:45
vuejs/vue
a00170cbb932e589ac243622385274a659019930
ada90e5e37c53cb56b76702dc0d223951523e7d6
remove unnecessary appear check in v-show (fix #3559)
[ { "path": "src/platforms/web/runtime/directives/show.js", "patch": "@@ -14,7 +14,7 @@ export default {\n bind (el: any, { value }: VNodeDirective, vnode: VNodeWithData) {\n vnode = locateNode(vnode)\n const transition = vnode.data && vnode.data.transition\n- if (value && transition && transitio...
2016-08-30T14:45:38
ggml-org/llama.cpp
1e19f5d462b6df490a13103ca555d851f47e5fa5
d2fcd91cf96b46f4485ce46b4e3a32bf0df37715
common : Add top-nsigma sampler to help globally (#15428) Fixes #15423.
[ { "path": "common/arg.cpp", "patch": "@@ -1830,7 +1830,7 @@ common_params_context common_params_parser_init(common_params & params, llama_ex\n [](common_params & params, const std::string & value) {\n params.sampling.top_n_sigma = std::stof(value);\n }\n- ).set_examples({LLAMA...
2025-08-19T16:58:14
denoland/deno
02f6e49276bb4c03634af4aec4487a5a0a9dbebf
18054af79e74b649c25df161aa0b054d1e1605eb
fix(fmt/json): support hexadecimal numbers, plus sign on numbers, and words with underscores (#31057)
[ { "path": ".dprint.json", "patch": "@@ -12,9 +12,14 @@\n \"quotes\": \"preferSingle\"\n },\n \"exec\": {\n+ \"cwd\": \"${configDir}\",\n \"commands\": [{\n \"command\": \"rustfmt --config imports_granularity=item --config group_imports=StdExternalCrate\",\n- \"exts\": [\"rs\"]\n+ ...
2025-10-22T20:54:29
huggingface/transformers
738b223f57fdef69e9db2de2f9e1203b43eef251
dd7ac4cd59563d455c9f700cc9119b2f79f8a865
Add captured actual outputs to CI artifacts (#40965) * fix * fix * Remove `# TODO: ???` as it make me `???` * fix * fix * fix --------- Co-authored-by: ydshieh <ydshieh@users.noreply.github.com>
[ { "path": ".github/workflows/model_jobs.yml", "patch": "@@ -128,28 +128,35 @@ jobs:\n echo \"machine_type=$machine_type\" >> $GITHUB_ENV\n echo \"machine_type=$machine_type\" >> $GITHUB_OUTPUT\n \n+ - name: Create report directory if it doesn't exist\n+ shell: bash\n+ ...
2025-09-18T13:40:53
vuejs/vue
32971d85884b2a5460183a158d069b4280b54631
8c427f7f18d34bca8e2860788d0849bee26d4bb9
fix v-on patching for cloned slot nodes (fix #3556)
[ { "path": "src/core/vdom/helpers.js", "patch": "@@ -104,13 +104,15 @@ export function updateListeners (\n }\n add(event, cur.invoker, capture)\n }\n- } else if (Array.isArray(old)) {\n- old.length = cur.length\n- for (let i = 0; i < old.length; i++) old[i] = cur[i]\n- ...
2016-08-29T22:45:07
ggml-org/llama.cpp
d1d82416006e7ff41780cb0e9b5f28d30a267497
618575c5825d7d4f170e686e772178d2aae148ae
server : fix incoming tasks not process in order (#15395)
[ { "path": "tools/server/server.cpp", "patch": "@@ -1729,7 +1729,7 @@ struct server_queue {\n void pop_deferred_task() {\n std::unique_lock<std::mutex> lock(mutex_tasks);\n if (!queue_tasks_deferred.empty()) {\n- queue_tasks.emplace_back(std::move(queue_tasks_deferred.front()))...
2025-08-18T14:51:42
huggingface/transformers
2ce35a248fac4abe0d4676f81ecaf4dd7875f8ce
6e51ac31effcd46c857869c6e210b6532a377aaa
Fix Issue #39030: AutoTokenizer.from_pretrained does not propagate token (#40956) * fix merge conflicts * change token typing --------- Co-authored-by: Ubuntu <ubuntu@ip-172-31-27-253.ec2.internal>
[ { "path": "src/transformers/processing_utils.py", "patch": "@@ -963,6 +963,7 @@ def get_processor_dict(\n local_files_only=local_files_only,\n revision=revision,\n cache_dir=cache_dir,\n+ token=token,\n ...
2025-09-18T13:22:19
denoland/deno
18054af79e74b649c25df161aa0b054d1e1605eb
d0db370d5cb5d646f172b8da2c5e46d045676f74
fix(npm): regression resolving npm bin for default when only one entry (#31055) Closes #31052
[ { "path": "libs/node_resolver/resolution.rs", "patch": "@@ -756,14 +756,8 @@ impl<\n ) -> Result<PathBuf, ResolvePkgJsonBinExportError> {\n let (pkg_json, items) = self\n .resolve_npm_binary_commands_for_package_with_pkg_json(package_folder)?;\n- let bin_name = match sub_path {\n- Some(b...
2025-10-22T17:59:53
ggml-org/llama.cpp
618575c5825d7d4f170e686e772178d2aae148ae
f44f7931729022c57319a0124931120a169e0da9
Fix broken build: require updated pip to support --break-system-packages (#15357) * Revert "devops : fix compile bug when the BASE_CUDA_DEV_CONTAINER is based on Ubuntu 24.04 (#15005)" This reverts commit e4e915912cfd2ee15c5a4a0074813232134892f6. * devops: Allow pip to modify externally-managed python environment (s...
[ { "path": ".devops/cuda.Dockerfile", "patch": "@@ -60,6 +60,7 @@ RUN apt-get update \\\n git \\\n python3 \\\n python3-pip \\\n+ && pip install --upgrade pip setuptools wheel \\\n && pip install --break-system-packages -r requirements.txt \\\n && apt autoremove -y \\\n && apt clea...
2025-08-18T10:50:48
vuejs/vue
a3314c8610a199cc2882f69b22da918b222c6329
f6b1a51729f705bc49c6eaaf32ec095efd97401c
Fixed "delcare" typo error (#3552) * Fixed "delcare" typo error * Revert "Fixed "delcare" typo error" This reverts commit 14c3563c48fe9fc68b413e468db221ea4430ade4. * Typo fixed on src folder only
[ { "path": "src/core/observer/index.js", "patch": "@@ -200,7 +200,7 @@ export function set (obj: Array<any> | Object, key: any, val: any) {\n if (obj._isVue || (ob && ob.vmCount)) {\n process.env.NODE_ENV !== 'production' && warn(\n 'Avoid adding reactive properties to a Vue instance or its root ...
2016-08-29T15:45:33
huggingface/transformers
6e51ac31effcd46c857869c6e210b6532a377aaa
9378f874c1c2bb6d03f1d6a639b1d56859966798
[timm_wrapper] better handling of "Unknown model" exception in timm (#40951) * fix(timm): Add exception handling for unknown Gemma3n model * nit: Let’s cater to this specific issue * nit: Simplify error handling
[ { "path": "src/transformers/models/timm_wrapper/modeling_timm_wrapper.py", "patch": "@@ -55,6 +55,28 @@ class TimmWrapperModelOutput(ModelOutput):\n attentions: Optional[tuple[torch.FloatTensor, ...]] = None\n \n \n+def _create_timm_model_with_error_handling(config: \"TimmWrapperConfig\", **model_kwargs...
2025-09-18T13:09:08
denoland/deno
2b0f277e96768ba345c99c80563b1ba739b90d4f
e4289491d7449e35e029e81ebf051de99fbd0ab0
fix(ext/node): `fs.read/fs.readSync` and `fs.write/fs.writeSync` compatibility (#31013) Towards #29972 - `fs.read` and `fs.readSync`: accepts object option parameter. - `fs.write` and `fs.writeSync`: negative position value defaults to the current seek position. - Allows several node compatibility tests to pass.
[ { "path": "ext/node/polyfills/_fs/_fs_common.ts", "patch": "@@ -15,7 +15,6 @@ import {\n notImplemented,\n TextEncodings,\n } from \"ext:deno_node/_utils.ts\";\n-import { type Buffer } from \"node:buffer\";\n import { assertEncoding } from \"ext:deno_node/internal/fs/utils.mjs\";\n \n export type Callba...
2025-10-22T08:48:42
ggml-org/llama.cpp
f44f7931729022c57319a0124931120a169e0da9
ae532eac2c1df1d8edc3d2719145895b966de1bf
ggml-quants : fix make_qp_quants NANs and IQ1 assertion errors (#15379) * ggml-quants : fix make_qp_quants NANs and IQ1 assertion errors * ggml-quants : avoid division by zero in make_q3_quants
[ { "path": "ggml/src/ggml-quants.c", "patch": "@@ -566,7 +566,7 @@ static float make_q3_quants(int n, int nmax, const float * GGML_RESTRICT x, int8\n for (int i = 0; i < n; ++i) {\n L[i] += nmax;\n }\n- return sumlx / suml2;\n+ return suml2 > 0.0f ? sumlx / suml2 : 0...
2025-08-18T07:23:56
vuejs/vue
f6b1a51729f705bc49c6eaaf32ec095efd97401c
22b3645ebb7ce1feb83c33cdc37f4cc30b03ad75
fix hot-reload not updating static nodes
[ { "path": "src/core/instance/render.js", "patch": "@@ -102,7 +102,7 @@ export function renderMixin (Vue: Class<Component>) {\n ): VNode | Array<VNode> {\n let tree = this._staticTrees[index]\n // if has already-rendered static tree and not inside v-for,\n- // we can reuse the same tree by inden...
2016-08-29T15:45:08
huggingface/transformers
9378f874c1c2bb6d03f1d6a639b1d56859966798
7cf1f5ced0bbf224e5e96a84b3f802f1da7b8b9f
[Trainer] Fix DP loss (#40799) * fix * style * Fix fp16 * style --------- Co-authored-by: Matej Sirovatka <54212263+S1ro1@users.noreply.github.com>
[ { "path": "src/transformers/trainer.py", "patch": "@@ -2483,8 +2483,7 @@ def _inner_training_loop(\n model, self.optimizer, self.lr_scheduler = self.accelerator.prepare(\n self.model, self.optimizer, self.lr_scheduler\n )\n- elif self.args.optim in ...
2025-09-18T13:07:20
denoland/deno
e4289491d7449e35e029e81ebf051de99fbd0ab0
9da9db0d46a3ad7faa7bbd3492969814441f154d
fix: regex pattern syntax in config-file.v1.json (#31038) Into `config-file.v1.json`, `compilerOptions.moduleResolution` has in invalid regexp pattern.
[ { "path": "cli/schemas/config-file.v1.json", "patch": "@@ -247,7 +247,7 @@\n ]\n },\n {\n- \"pattern\": \"^([Nn]ode[Nn]ext)|([Bb]undler))$\"\n+ \"pattern\": \"^([Nn]ode[Nn]ext|[Bb]undler)$\"\n }\n ],\n \"markdown...
2025-10-22T08:08:39
ggml-org/llama.cpp
b143fbc87af0324aa49e16cd91faf3ba8bb22231
de5627910df74298c998e6bb36ee3217375a5719
ci : fix hang in windows-hip build/release (#15365) * fix hang in windows-latest-cmake-hip * apply fix to release as well
[ { "path": ".github/workflows/build.yml", "patch": "@@ -1070,7 +1070,8 @@ jobs:\n write-host \"Downloading AMD HIP SDK Installer\"\n Invoke-WebRequest -Uri \"https://download.amd.com/developer/eula/rocm-hub/AMD-Software-PRO-Edition-24.Q3-WinSvr2022-For-HIP.exe\" -OutFile \"${env:RUNNER_TE...
2025-08-17T11:30:23
vuejs/vue
c44f68d25e16feba9bb2868fd378173856c9f819
72710db4f4ce220f7f8f8a6b400e48d0fc747dcc
fix dev scripts
[ { "path": "package.json", "patch": "@@ -10,10 +10,10 @@\n \"src\"\n ],\n \"scripts\": {\n- \"dev\": \"TARGET=web-standalone-dev rollup --w --c build/config.js\",\n+ \"dev\": \"TARGET=web-standalone-dev rollup -w -c build/config.js\",\n \"dev:test\": \"karma start build/karma.dev.config.js\...
2016-08-28T14:43:19
huggingface/transformers
f6104189fda98a39757fd456b65261edfd183e65
c532575795e4ccbf3c912a457528a9a60c0b94de
Fix outdated version checks of accelerator (#40969) * Fix outdated version checks of accelerator Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> * Fix outdated version checks of accelerator Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> --------- Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
[ { "path": "src/transformers/trainer.py", "patch": "@@ -241,10 +241,9 @@\n DATA_SAMPLERS = [RandomSampler]\n if version.parse(accelerate_version) > version.parse(\"1.3.0\"):\n from accelerate.utils import TorchTensorParallelPlugin\n- if version.parse(accelerate_version) > version.parse(\"0...
2025-09-18T11:49:14
denoland/deno
9da9db0d46a3ad7faa7bbd3492969814441f154d
34dea6098ed4ce88ee8fd86f2561cf69c8e58dd0
fix(check): error when type checking after deduping packages (#31049)
[ { "path": "Cargo.lock", "patch": "@@ -2192,9 +2192,9 @@ dependencies = [\n \n [[package]]\n name = \"deno_graph\"\n-version = \"0.103.0\"\n+version = \"0.103.1\"\n source = \"registry+https://github.com/rust-lang/crates.io-index\"\n-checksum = \"2594e83855f172895f0e391099ca5d09dc8ae1072789c7e9ed3c3dc52a267d...
2025-10-22T03:11:01
ggml-org/llama.cpp
65349f26f2299e06477ec8e85e46243046801358
1fe00296f587dfca0957e006d146f5875b61e43d
model : support vision LiquidAI LFM2-VL family (#15347) * wip lfm2 vision model * Fix conv weight * Implement dynamic resolution * Fix cuda * support LFM2-VL-450M * happy CI * Remove extra `ggml_conv` and put others into the right place Co-authored-by: Sigbjørn Skjæret <sigbjorn.skjaeret@scala.com> --------- ...
[ { "path": "convert_hf_to_gguf.py", "patch": "@@ -8251,8 +8251,7 @@ def set_gguf_parameters(self):\n self.gguf_writer.add_rope_scaling_orig_ctx_len(rope_scaling.get(\"original_max_position_embeddings\", 4096))\n \n \n-@ModelBase.register(\"Lfm2ForCausalLM\")\n-@ModelBase.register(\"LFM2ForCausalLM\")...
2025-08-16T21:33:54
vuejs/vue
98876f008b4e2ce0864c72a77e251cd8c5f5c2d4
4d640ce4d9fd638bcd0e4a61a8bb346458046ced
ensure transition end detection only count events triggered on target element (fix #3506)
[ { "path": "src/platforms/web/runtime/transition-util.js", "patch": "@@ -60,9 +60,11 @@ export function whenTransitionEnds (\n el.removeEventListener(event, onEnd)\n cb()\n }\n- const onEnd = () => {\n- if (++ended >= propCount) {\n- end()\n+ const onEnd = e => {\n+ if (e.target === el...
2016-08-27T21:14:25
denoland/deno
0f81808c8823304b28619b2afb121883a3973f04
568e247187dba08c812a74b1a5d4415f790eee99
fix(coverage): don't process coverage for blob: urls (#31035) Fixes #31030.
[ { "path": "cli/tools/coverage/mod.rs", "patch": "@@ -441,6 +441,7 @@ fn filter_coverages(\n .filter(|e| {\n let is_internal = e.url.starts_with(\"ext:\")\n || e.url.starts_with(\"data:\")\n+ || e.url.starts_with(\"blob:\")\n || e.url.ends_with(\"__anonymous__\")\n ||...
2025-10-21T06:59:21
ggml-org/llama.cpp
1fe00296f587dfca0957e006d146f5875b61e43d
de2192794f4e8e04f2e8167ef2424905145e88fc
vulkan: fuse adds (#15252) * vulkan: fuse adds Fuse adds that have the same shape, which are common in MoE models. It will currently fuse up to 6 adds, because we assume no more than 8 descriptors per dispatch. But this could be changed. * check runtimeDescriptorArray feature * disable multi_add for Intel due to li...
[ { "path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp", "patch": "@@ -103,6 +103,8 @@ static bool is_pow2(uint32_t x) { return x > 1 && (x & (x-1)) == 0; }\n struct ggml_backend_vk_context;\n \n #define MAX_PARAMETER_COUNT 8\n+// Max number of adds that can be fused without exceeding MAX_PARAMETER_COUNT.\n+#defin...
2025-08-16T16:48:22
vuejs/vue
014d2f8599f9afc0754e603b1528a12e74bd209a
ed2085974b2a385ca1fd8cd696917d6cda8322e7
fix vdom patch edge case for static nodes being reused and as insertion reference node (fix #3533)
[ { "path": "src/core/instance/render.js", "patch": "@@ -1,7 +1,7 @@\n /* @flow */\n \n import config from '../config'\n-import VNode, { emptyVNode } from '../vdom/vnode'\n+import VNode, { emptyVNode, cloneVNode, cloneVNodes } from '../vdom/vnode'\n import { normalizeChildren } from '../vdom/helpers'\n import...
2016-08-27T20:29:07
huggingface/transformers
c532575795e4ccbf3c912a457528a9a60c0b94de
564fde14f1553c1b0e7890fbcec85b86c762d8c3
Add new model LFM2-VL (#40624) * Add LFM2-VL support * add tests * linting, formatting, misc review changes * add siglip2 to auto config and instantiate it in lfm2-vl configuration * decouple image processor from processor * remove torch import from configuration * replace | with Optional * remove layer truncat...
[ { "path": "docs/source/en/_toctree.yml", "patch": "@@ -555,6 +555,8 @@\n title: LED\n - local: model_doc/lfm2\n title: LFM2\n+ - local: model_doc/lfm2_vl\n+ title: LFM2-VL\n - local: model_doc/llama\n title: LLaMA\n - local: model_doc/llama2", "addit...
2025-09-18T11:01:58
ggml-org/llama.cpp
de2192794f4e8e04f2e8167ef2424905145e88fc
2e2b22ba6607414a5d619ac6d2f034b5b02214e5
vulkan: Support mul_mat_id with f32 accumulators (#15337) * vulkan: Add missing bounds checking to scalar/coopmat1 mul_mat_id * vulkan: Support mul_mat_id with f32 accumulators, but they are not hooked up - There's no explicit way to request f32 precision for mul_mat_id, but there probably should be, and this gets t...
[ { "path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp", "patch": "@@ -2387,26 +2387,26 @@ static void ggml_vk_load_shaders(vk_device& device) {\n CREATE_MM(pipeline_matmul_id_bf16, matmul_id_bf16, , wg_denoms, warptile, vk_mat_mat_id_push_constants, 4)\n }\n #endif\n- CREATE_MM(pipeline...
2025-08-16T09:18:31
denoland/deno
ec3ece4ec38a0c14b0101761c39b431f0e21e46f
d38b20ca7a73b213f2322f3118cd459b40694bf9
fix(kv): do not error when creating kv db with relative path and `-A` (#31021) This upgrades `deno_path_util` from 0.6.1 to 0.6.3, which includes a fix for path normalization of relative paths. This resolves issues where `Deno.openKv()` would fail with "NotFound" errors when using `-A` flag with relative paths that do...
[ { "path": "Cargo.lock", "patch": "@@ -2717,9 +2717,9 @@ dependencies = [\n \n [[package]]\n name = \"deno_path_util\"\n-version = \"0.6.1\"\n+version = \"0.6.3\"\n source = \"registry+https://github.com/rust-lang/crates.io-index\"\n-checksum = \"bfe02936964b2910719bd488841f6e884349360113c7abf6f4c6b28ca9cd7a...
2025-10-21T03:21:30
huggingface/transformers
564fde14f1553c1b0e7890fbcec85b86c762d8c3
5748352c27ffa5f26055836474a345daa2291df8
FIX(trainer): ensure final checkpoint is saved when resuming training (#40347) * fix(trainer): ensure final checkpoint is saved when resuming training * add test * make style && slight fix of test * make style again * move test code to test_trainer * remove outdated test file * Apply style fixes --------- Co-a...
[ { "path": "src/transformers/trainer.py", "patch": "@@ -2533,7 +2533,6 @@ def _inner_training_loop(\n start_time = time.time()\n epochs_trained = 0\n steps_trained_in_current_epoch = 0\n- steps_trained_progress_bar = None\n \n # Check if continuing training from a check...
2025-09-18T09:57:21
vuejs/vue
44128f2ac745d84f12e20b73d2f9336510b23c9b
3fa4076d05c6de7c7d3485376182323401bea375
remove forgotten debugger statement
[ { "path": "src/core/vdom/helpers.js", "patch": "@@ -129,7 +129,6 @@ function arrInvoker (arr: Array<Function>): Function {\n function fnInvoker (o: { fn: Function }): Function {\n return function (ev) {\n const single = arguments.length === 1\n- if (typeof o.fn !== 'function') debugger\n single...
2016-08-26T23:11:45
denoland/deno
d38b20ca7a73b213f2322f3118cd459b40694bf9
243857c362793beb5f048d178bd665fb29ba0696
test: disable test-fs-glob.mjs (#31029) This test is currently crashing on CI all the time. Disabling for the time being.
[ { "path": "tests/node_compat/config.toml", "patch": "@@ -441,7 +441,8 @@\n \"parallel/test-fs-existssync-false.js\" = {}\n \"parallel/test-fs-fchown.js\" = {}\n \"parallel/test-fs-fsync.js\" = {}\n-\"parallel/test-fs-glob.mjs\" = {}\n+# TODO(bartlomieju): crashes constantly on CI, disabling for now\n+# \"pa...
2025-10-20T18:59:31
ggml-org/llama.cpp
912ff8c119f01ae029543c7fdf7a84f91a0437a3
5e6229a8409ac786e62cb133d09f1679a9aec13e
OpenCL: add initial FA support (#14987) * add F16/F16 fa support * fix kernel init * use mad instead of fma * use inline function * mark FA with sinks as unsupported for now * add pragma unroll to loops
[ { "path": "ggml/src/ggml-opencl/CMakeLists.txt", "patch": "@@ -112,6 +112,9 @@ set(GGML_OPENCL_KERNELS\n mul_mat_f16_f32\n conv2d\n conv2d_f16_f32\n+ flash_attn_f32_f16\n+ flash_attn_f16\n+ flash_attn_f32\n )\n \n foreach (K ${GGML_OPENCL_KERNELS})", "additions": 3, "deletions":...
2025-08-16T08:05:55
huggingface/transformers
5748352c27ffa5f26055836474a345daa2291df8
438343d93f08d6f1f7c67933aaadf014ce719b4c
Update expected values for one more `test_speculative_generation` after #40949 (#40967) fix Co-authored-by: ydshieh <ydshieh@users.noreply.github.com>
[ { "path": "tests/models/qwen3_moe/test_modeling_qwen3_moe.py", "patch": "@@ -232,7 +232,7 @@ def test_model_15b_a2b_long_prompt_sdpa(self):\n @slow\n def test_speculative_generation(self):\n EXPECTED_TEXT_COMPLETION = (\n- \"To be or not to be: the role of the liver in the pathoge...
2025-09-18T09:47:14
vuejs/vue
3fa4076d05c6de7c7d3485376182323401bea375
3627a27179e2fc4c16d3d0eedc2cd89cfd7d77a2
fix text parser regex for multiline tags (fix #3526)
[ { "path": "src/compiler/parser/text-parser.js", "patch": "@@ -3,7 +3,7 @@\n import { cached } from 'shared/util'\n import { parseFilters } from './filter-parser'\n \n-const defaultTagRE = /\\{\\{((?:.|\\\\n)+?)\\}\\}/g\n+const defaultTagRE = /\\{\\{((?:.|\\n)+?)\\}\\}/g\n const regexEscapeRE = /[-.*+?^${}()...
2016-08-26T22:56:33
huggingface/transformers
58e13b9f129bb0dccc3b51e5da22f45ef3ff0ae7
529d3a2b063e8318007111db04d20071b0db1721
Update expected values for some `test_speculative_generation` (#40949) * fix * fix --------- Co-authored-by: ydshieh <ydshieh@users.noreply.github.com>
[ { "path": "tests/models/mistral/test_modeling_mistral.py", "patch": "@@ -254,7 +254,7 @@ def test_model_7b_long_prompt_sdpa(self):\n \n @slow\n def test_speculative_generation(self):\n- EXPECTED_TEXT_COMPLETION = \"My favourite condiment is 100% Sriracha. I love it on everything. I have it on...
2025-09-17T18:50:38
denoland/deno
243857c362793beb5f048d178bd665fb29ba0696
9e572c78750bb721ae1ece2b2ffaa0589870112f
fix(ext/node): false deprecation warning on `crypto.createHmac` (#31025) Co-authored-by: Bartek Iwańczuk <biwanczuk@gmail.com>
[ { "path": "ext/node/polyfills/crypto.ts", "patch": "@@ -329,7 +329,7 @@ function createHmac(\n key: string | ArrayBuffer | KeyObject,\n options?: TransformOptions,\n ) {\n- return Hmac(hmac, key, options);\n+ return Hmac_(hmac, key, options);\n }\n \n function createSign(algorithm: string, options?: W...
2025-10-20T18:22:25
vuejs/vue
a152fe0e98b621010e6d9bd71c07e1120b7fbea0
e6c5f21f86c3d2de4821c99566dba364c18b4c19
only gen checkbox/radio model on input tags (fix #3516)
[ { "path": "src/platforms/web/compiler/directives/model.js", "patch": "@@ -13,19 +13,16 @@ export default function model (\n warn = _warn\n const value = dir.value\n const modifiers = dir.modifiers\n- if (el.tag === 'select') {\n+ const tag = el.tag\n+ const type = el.attrsMap.type\n+ if (tag === '...
2016-08-26T22:28:58
ggml-org/llama.cpp
5e6229a8409ac786e62cb133d09f1679a9aec13e
e2c1bfff5305c661ac53e9d57cb732ff626a2242
common : fix double bos, use common_chat_templates for add_bos and add_eos (#15326) This commit updates common_chat_templates_apply_jinja to use the the add_bos and add_eos parameters from the chat template instead of the inputs. The motivation for this is that currently if the `add_bos` and `add_eos` from the input ...
[ { "path": "common/chat.cpp", "patch": "@@ -2061,8 +2061,8 @@ static common_chat_params common_chat_templates_apply_jinja(\n params.enable_thinking = inputs.enable_thinking;\n params.grammar = inputs.grammar;\n params.now = inputs.now;\n- params.add_bos = inputs.add_bos;\n- params.add_eos =...
2025-08-15T17:50:52
huggingface/transformers
529d3a2b063e8318007111db04d20071b0db1721
a2ac4de8b0af2776e3156e72afa7bb8679a3e436
Fix `Glm4vModelTest::test_eager_matches_fa2_generate` (#40947) * fix * fix * fix --------- Co-authored-by: ydshieh <ydshieh@users.noreply.github.com>
[ { "path": "tests/models/glm4v/test_modeling_glm4v.py", "patch": "@@ -159,7 +159,9 @@ def prepare_config_and_inputs_for_common(self):\n \n inputs_dict = {\n \"pixel_values\": pixel_values,\n- \"image_grid_thw\": torch.tensor([[1, patches_per_side, patches_per_side]] * self.batc...
2025-09-17T17:53:59
denoland/deno
9e572c78750bb721ae1ece2b2ffaa0589870112f
b252cc78c2b426a3b2ebfacd942aa9908785dfc4
fix(unstable): read npm lazy caching from unstable config in deno.json as well (#31026)
[ { "path": "cli/args/mod.rs", "patch": "@@ -1370,7 +1370,7 @@ impl CliOptions {\n | DenoSubcommand::Outdated(_)\n ) {\n NpmCachingStrategy::Manual\n- } else if self.flags.unstable_config.npm_lazy_caching {\n+ } else if self.unstable_npm_lazy_caching() {\n NpmCachingStrategy::Laz...
2025-10-20T17:59:50
vuejs/vue
e6c5f21f86c3d2de4821c99566dba364c18b4c19
067450919377254bd194d7aa172ff53a7c97adbb
fix event initialization on reused slot nodes (fix #3518)
[ { "path": "src/core/vdom/helpers.js", "patch": "@@ -92,10 +92,13 @@ export function updateListeners (\n if (Array.isArray(cur)) {\n add(event, (cur.invoker = arrInvoker(cur)), capture)\n } else {\n- fn = cur\n- cur = on[name] = {}\n- cur.fn = fn\n- add(event, ...
2016-08-26T22:23:18
ggml-org/llama.cpp
e2c1bfff5305c661ac53e9d57cb732ff626a2242
5edf1592fdb9131d01321aeef4241c6a34969e27
opencl: add initial mxfp4 support via mv (#15270) * opencl: add reference `mul_mv_mxfp4_f32` * opencl: add reference `mul_mv_id` for mxfp4 * Q4_0 tranpose fix for Adreno --------- Co-authored-by: shawngu-quic <shawngu@qti.qualcomm.com>
[ { "path": "ggml/src/ggml-opencl/CMakeLists.txt", "patch": "@@ -82,7 +82,9 @@ set(GGML_OPENCL_KERNELS\n mul_mv_q4_0_f32_1d_8x_flat\n mul_mv_q4_0_f32_1d_16x_flat\n mul_mv_q6_k\n+ mul_mv_mxfp4_f32\n mul_mv_id_q4_0_f32_8x_flat\n+ mul_mv_id_mxfp4_f32\n mul_mm_f32_f32_l4_lm\n mul_mm_...
2025-08-15T16:52:14
denoland/deno
48f273b8c916a3cab5dd3aadc11b541647813790
9e21ce5532ed3e6ac90d04a90f6c1b5ffb4f52b4
fix(ext/node): process.moduleLoadList as undefined (#31022)
[ { "path": "ext/node/polyfills/process.ts", "patch": "@@ -833,6 +833,8 @@ process.features = { inspector: false };\n // TODO(kt3k): Get the value from --no-deprecation flag.\n process.noDeprecation = false;\n \n+process.moduleLoadList = [];\n+\n if (isWindows) {\n delete process.getgid;\n delete process....
2025-10-20T14:51:46
huggingface/transformers
a2ac4de8b0af2776e3156e72afa7bb8679a3e436
8e837f6ae244cd5be0d9629e695f60b054f16cb5
Remove nested import logic for torchvision (#40940) * remove nested import logic for torchvision * remove unnecessary protected imports * remove unnecessarry protected import in modular (and modeling) * fix wrongly remove protected imports
[ { "path": "src/transformers/image_processing_utils_fast.py", "patch": "@@ -61,14 +61,14 @@\n \n if is_torchvision_available():\n from .image_utils import pil_torch_interpolation_mapping\n-\n- if is_torchvision_v2_available():\n- from torchvision.transforms.v2 import functional as F\n- else:...
2025-09-17T17:34:30
vuejs/vue
067450919377254bd194d7aa172ff53a7c97adbb
eef040ebd0c459a9ee7ed930b0b9a530803687ba
avoid triggering select reset when selectedIndex has not changed (fix #3504)
[ { "path": "src/platforms/web/runtime/directives/model.js", "patch": "@@ -64,9 +64,7 @@ export default {\n function setSelected (el, binding, vm) {\n const value = binding.value\n const isMultiple = el.multiple\n- if (!isMultiple) {\n- el.selectedIndex = -1\n- } else if (!Array.isArray(value)) {\n+ ...
2016-08-23T14:30:40
ggml-org/llama.cpp
5edf1592fdb9131d01321aeef4241c6a34969e27
db3010bd23980bad5f5d93ec3e6757ec531a413b
vulkan : fix out-of-bounds access in argmax kernel (#15342) ggml-ci
[ { "path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp", "patch": "@@ -8392,7 +8392,7 @@ static void ggml_vk_sum_rows(ggml_backend_vk_context * ctx, vk_context& subctx,\n }\n \n static void ggml_vk_argmax(ggml_backend_vk_context * ctx, vk_context& subctx, const ggml_tensor * src0, ggml_tensor * dst, bool dryrun = ...
2025-08-15T14:16:36
denoland/deno
00353e7494b093f9ffd82c11e922718a302806e6
7912110a938bc41c204d94f491bc4b93c6e0385a
fix(npm): occasional panic when upgrading npm package constraints (#31006) Closes https://github.com/denoland/deno/issues/30997
[ { "path": "Cargo.lock", "patch": "@@ -2559,9 +2559,9 @@ dependencies = [\n \n [[package]]\n name = \"deno_npm\"\n-version = \"0.41.0\"\n+version = \"0.41.1\"\n source = \"registry+https://github.com/rust-lang/crates.io-index\"\n-checksum = \"00d083e04150ff9a330abe8f7a9f702dc9bee98b5d438b27d4ab975dc55fbd5c\"...
2025-10-17T16:38:27
vuejs/vue
eef040ebd0c459a9ee7ed930b0b9a530803687ba
0f8ad06b2c580fd9e484b2d559a59fc06914f22a
vdom: teardown stale directives on patch (fix #3491)
[ { "path": "src/core/vdom/modules/directives.js", "patch": "@@ -8,6 +8,11 @@ export default {\n },\n update: function updateDirectives (oldVnode: VNodeWithData, vnode: VNodeWithData) {\n applyDirectives(oldVnode, vnode, 'update')\n+ // if old vnode has directives but new vnode doesn't\n+ // we ...
2016-08-23T10:01:21
ggml-org/llama.cpp
db3010bd23980bad5f5d93ec3e6757ec531a413b
ff27f80a74bbe5303acd511a6781a1de6d619b3c
vulkan : fix compile warnings on macos (#15340) ggml-ci
[ { "path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp", "patch": "@@ -8360,7 +8360,7 @@ static void ggml_vk_rope(ggml_backend_vk_context * ctx, vk_context& subctx, cons\n (uint32_t)src0->ne[0], (uint32_t)n_dims, freq_scale, (uint32_t)src0->ne[1],\n freq_base, ext_factor, attn_factor, {corr_dims[0]...
2025-08-15T13:28:28